@@ -21,6 +21,7 @@ from python_kemptech_api.exceptions import (
     SubVsCannotCreateSubVs,
     BackupFailed,
 )
+from python_kemptech_api.capabilities import CAPABILITIES, DEFAULT
 from .utils import (
     validate_port,
     validate_ip,
@@ -129,6 +130,7 @@ class LoadMaster(HttpClient):
         self.username = username
         self.password = password
         self.port = port
+        self.version = None
 
     def __repr__(self):
         return '{}:{}'.format(self.ip_address, self.port)
@@ -149,6 +151,13 @@ class LoadMaster(HttpClient):
             "ip_address": self.ip_address,
         }
 
+    @property
+    def capabilities(self):
+        if self.version is None:
+            full_version = self.get_parameter("version")
+            self.version = ".".join(full_version.split("."[:3]))
+        return CAPABILITIES.get(self.version, CAPABILITIES[DEFAULT])
+
     def create_virtual_service(self, ip, port=80, protocol="tcp"):
         """VirtualService factory with pre-configured LoadMaster connection."""
         vs = VirtualService(self.access_info, ip, port, protocol)
@@ -334,10 +343,12 @@ class LoadMaster(HttpClient):
 
     def update_firmware(self, file):
         response = self._post('/installpatch', file)
+        self.version = None
         return is_successful(response)
 
     def restore_firmware(self):
         response = self._get("/restorepatch")
+        self.version = None
         return is_successful(response)
 
     def shutdown(self):
